==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>De authenticatie is verlopen</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Schijf is in gebruik; je kunt nu niet afkoppelen</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Schijf is in gebruik; je kunt nu niet uitwerpen</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Schijf is in gebruik; je kunt nu niet uitwerpen</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Schijf is in gebruik; je kunt nu niet afkoppelen</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Het apparaat is niet veilig verwijderd</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klik voortaan op &apos;Veilig verwijderen&apos; voordat je het apparaat loskoppelt</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Schijf is in gebruik; je kunt nu niet uitwerpen</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Schijf is in gebruik; je kunt nu niet afkoppelen</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Kan apparaat niet afkoppelen</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>De schijf is aangekoppeld door gebruiker &quot;%1&quot;. Je kunt deze daarom niet afkoppelen.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Het aangekoppelde apparaat is niet aangetroffen</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Schijven</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Schijf</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Alles uitwerpen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Het apparaat is veilig verwijderd</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Toegang geweigerd</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Je bent niet bevoegd om deze map te openen</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Wil je het doorzoeken van het apparaat afbreken?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Afbreken</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>De authenticatie is verlopen</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Schijf is in gebruik; je kunt nu niet afkoppelen</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Schijf is in gebruik; je kunt nu niet uitwerpen</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Schijf is in gebruik; je kunt nu niet uitwerpen</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Schijf is in gebruik; je kunt nu niet afkoppelen</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volume %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Het apparaat is niet veilig verwijderd</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klik voortaan op ‘Veilig verwijderen’ voordat je het apparaat loskoppelt</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Kan apparaat niet afkoppelen</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>De schijf is aangekoppeld door gebruiker &quot;%1&quot;. Je kunt deze daarom niet afkoppelen.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Het aangekoppelde apparaat is niet aangetroffen</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Schijven</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Schijf</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Alles uitwerpen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Het apparaat is veilig verwijderd</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Toegang geweigerd</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Je bent niet bevoegd om deze map te openen</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Wil je het doorzoeken van het apparaat afbreken?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Afbreken</translation>
    </message>
</context>
</TS>
